@@ -12,7 +12,7 @@ package Jedi;
 
 use Moo;
 
-our $VERSION = '1.003';    # VERSION
+our $VERSION = '1.004';    # VERSION
 
 use Jedi::Helpers::Scalar;
 use Jedi::Request;
@@ -30,7 +30,8 @@ sub road {
     my ( $self, $base_route, $module ) = @_;
     $base_route = $base_route->full_path();
 
-    my $jedi = use_module($module)->new( jedi_config => $self->config );
+    my $jedi = use_module($module)
+        ->new( jedi_config => $self->config, jedi_base_route => $base_route );
     croak "$module is not a jedi app" unless $jedi->does('Jedi::Role::App');
 
     $jedi->jedi_app;
@@ -117,7 +118,7 @@ Jedi - Web App Framework
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 DESCRIPTION
 
